Kwant is a free (open source) Python package for numerical calculations on
tight-binding models with a strong focus on quantum transport. It is designed to
be flexible and easy to use. Thanks to the use of innovative algorithms, Kwant
is often faster than other available codes, even those entirely written in the
low level FORTRAN and C/C++ languages.

Tight-binding models can describe a vast variety of systems and phenomena in
quantum physics. Therefore, Kwant can be used to simulate

* metals,
* graphene,
* topological insulators,
* quantum Hall effect,
* superconductivity,
* spintronics,
* molecular electronics,
* any combination of the above, and many other things.

Kwant can calculate

* transport properties (conductance, noise, scattering matrix),
* dispersion relations,
* modes,
* wave functions,
* various Green’s functions,
* out-of-equilibrium local quantities.

Other computations involving tight-binding Hamiltonians can be implemented
easily.

See the `Kwant web site <http://kwant-project.org/>`_ for the latest stable
version.  The current development version is available via the `Kwant gitlab
instance <https://gitlab.kwant-project.org/kwant/kwant>`_.  Contributions are
welcome.

A `mailing list <http://kwant-project.org/community>`_ exists for general
discussions related to Kwant.  Please report bugs and other issues using the
`issue tracker <https://gitlab.kwant-project.org/kwant/kwant/issues>`_.

See also in this directory: `<INSTALL.rst>`_, `<LICENSE.rst>`_, `<AUTHORS.rst>`_,
`<CITING.rst>`_, `<CONTRIBUTE.rst>`_.
